@@ -1,12 +1,20 @@
 package Module::Build::Platform::Unix;
 
 use strict;
-use warnings;
-our $VERSION = '0.42_35';
+use vars qw($VERSION);
+$VERSION = '0.2808_02';
 $VERSION = eval $VERSION;
 use Module::Build::Base;
 
-our @ISA = qw(Module::Build::Base);
+use vars qw(@ISA);
+@ISA = qw(Module::Build::Base);
+
+sub make_tarball {
+  my $self = shift;
+  $self->{args}{tar}  ||= ['tar'];
+  $self->{args}{gzip} ||= ['gzip'];
+  $self->SUPER::make_tarball(@_);
+}
 
 sub is_executable {
   # We consider the owner bit to be authoritative on a file, because
@@ -34,16 +42,12 @@ sub _construct {
   return $self;
 }
 
-# Open group says username should be portable filename characters,
-# but some Unix OS working with ActiveDirectory wind up with user-names
-# with back-slashes in the name.  The new code below is very liberal
-# in what it accepts.
 sub _detildefy {
   my ($self, $value) = @_;
-  $value =~ s[^~([^/]+)?(?=/|$)]   # tilde with optional username
+  $value =~ s[^~(\w[-\w]*)?(?=/|$)]   # tilde with optional username
     [$1 ?
-     (eval{(getpwnam $1)[7]} || "~$1") :
-     ($ENV{HOME} || eval{(getpwuid $>)[7]} || glob("~"))
+     ((getpwnam $1)[7] || "~$1") :
+     (getpwuid $>)[7]
     ]ex;
   return $value;
 }
