@@ -1,12 +1,13 @@
 package Module::Build::Platform::VOS;
 
 use strict;
-use warnings;
-our $VERSION = '0.42_35';
+use vars qw($VERSION);
+$VERSION = '0.2808_02';
 $VERSION = eval $VERSION;
 use Module::Build::Base;
 
-our @ISA = qw(Module::Build::Base);
+use vars qw(@ISA);
+@ISA = qw(Module::Build::Base);
 
 
 1;
